@@ -1,24 +1,27 @@
-(* Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>,
- *                          Claudio Sacerdoti Coen <sacerdot@cs.unibo.it>.
+(* Copyright (C) 2000-2005,
+ *    Luca Padovani	      <lpadovan@cs.unibo.it>
+ *    Claudio Sacerdoti Coen  <sacerdot@cs.unibo.it>
+ *    Stefano Zacchiroli      <zacchiro@cs.unibo.it>
  *
- * This file is part of lablgtkmathview, the Ocaml binding
- * for the GtkMathView widget.
+ * This file is part of lablgtkmathview, the Ocaml binding for the
+ * GtkMathView widget.
  * 
  * lablgtkmathview is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
  * lablgtkmathview is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with lablgtkmathview; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  * 
- * For details, send a mail to the author.
+ * For details, send a mail to the authors.
  *)
 
 (* finds the common node ancestor of two nodes *)
@@ -255,21 +258,6 @@ class multi_selection_math_view obj =
          if not (List.mem `CONTROL (Gdk.Convert.modifier state)) then
           self#remove_selections)) ;
 
-    ignore
-     (self#connect#select_over
-       (fun (_,_,_,state) ->
-         let c = 
-          function
-             `SHIFT -> "shift "
-           | `LOCK -> "lock "
-           | `CONTROL -> "control "
-           | `MOD1 -> "mod1 "
-           | _ -> ""
-         in
-          List.iter (fun x -> print_string (c x)) (Gdk.Convert.modifier state) ;
-          print_char '\n' ;
-          flush stdout)) ;
-
     ignore
      (self#connect#select_end
        (fun (_,_,_,state) ->
